==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1JenkinsAgentBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1JenkinsAgentBuilder extends V1alpha1JenkinsAgentFluentImpl<V1alpha1JenkinsAgentBuilder> implements VisitableBuilder<V1alpha1JenkinsAgent,V1alpha1JenkinsAgentBuilder>{

    V1alpha1JenkinsAgentFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1JenkinsAgentBuilder(){
            this(true);
    }
    public V1alpha1JenkinsAgentBuilder(Boolean validationEnabled){
            this(new V1alpha1JenkinsAgent(), validationEnabled);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1JenkinsAgent(), validationEnabled);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,V1alpha1JenkinsAgent instance){
            this(fluent, instance, true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,V1alpha1JenkinsAgent instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLabel(instance.getLabel());

            fluent.withRaw(instance.getRaw());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgent instance){
            this(instance,true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgent instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLabel(instance.getLabel());

            this.withRaw(instance.getRaw());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1JenkinsAgent build(){
            V1alpha1JenkinsAgent buildable = new V1alpha1JenkinsAgent();
            buildable.setLabel(fluent.getLabel());
            buildable.setRaw(fluent.getRaw());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1JenkinsAgentBuilder that = (V1alpha1JenkinsAgentBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1JenkinsAgentBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1JenkinsAgentBuilder extends V1alpha1JenkinsAgentFluentImpl<V1alpha1JenkinsAgentBuilder> implements VisitableBuilder<V1alpha1JenkinsAgent,V1alpha1JenkinsAgentBuilder>{

    V1alpha1JenkinsAgentFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1JenkinsAgentBuilder(){
            this(true);
    }
    public V1alpha1JenkinsAgentBuilder(Boolean validationEnabled){
            this(new V1alpha1JenkinsAgent(), validationEnabled);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1JenkinsAgent(), validationEnabled);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,V1alpha1JenkinsAgent instance){
            this(fluent, instance, true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgentFluent<?> fluent,V1alpha1JenkinsAgent instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLabel(instance.getLabel());

            fluent.withLabelMatcher(instance.getLabelMatcher());

            fluent.withRaw(instance.getRaw());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgent instance){
            this(instance,true);
    }
    public V1alpha1JenkinsAgentBuilder(V1alpha1JenkinsAgent instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLabel(instance.getLabel());

            this.withLabelMatcher(instance.getLabelMatcher());

            this.withRaw(instance.getRaw());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1JenkinsAgent build(){
            V1alpha1JenkinsAgent buildable = new V1alpha1JenkinsAgent();
            buildable.setLabel(fluent.getLabel());
            buildable.setLabelMatcher(fluent.getLabelMatcher());
            buildable.setRaw(fluent.getRaw());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1JenkinsAgentBuilder that = (V1alpha1JenkinsAgentBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
